import type { App, ComponentInternalInstance } from 'vue';
import type { Container, Abstract, Newable } from 'diod';
import { VueDiodConfiguration } from '../types';
import { ContainerBuilder } from 'diod';
/**
 * The VueDiod builder for injectables.
 */
export declare class VueDiodBuilder {
    /**
     * The Diod builder.
     */
    private readonly _builder;
    /**
     * The built container.
     */
    private _container?;
    /**
     * Registers and use the couples abstraction / implementation to be injected.
     *
     * @param { App | (T extends Component<infer P> ? Partial<P> : never) }
     * The application or component to inject the dependencies in.
     * @param { VueDiodConfiguration } config The VueDiod configuration object,
     */
    bootstrap(target: App | ComponentInternalInstance | undefined | null, config: VueDiodConfiguration): void;
    /**
     * 'Provide' the bootstrapped services at app or component level.
     * Method is also responsible of providing tagged services or services
     * that have been referenced by a token.
     *
     * @param target
     * @param config
     * @private
     */
    private _provide;
    /**
     * Prepares component by adding a custom 'provide' method, then calls the
     * private method '_provide'.
     *
     * @param { any } target
     * The component to inject the dependencies in.
     * @param { VueDiodConfiguration } config The VueDiod configuration object,
     * with the mandatory entry 'injectables'.
     * @private
     */
    private _provideComponent;
    /**
     * Checks if a given valass is registered.
     * @param { Abstract<T> | Newable<T> } identifier The identifier of
     * the dependency.
     * @returns { boolean } true if registered, false if not.
     */
    isRegistered<T>(identifier: Abstract<T> | Newable<T>): boolean;
    /**
     * The native DIOD builder for this instance of VueDiodBuilder.
     * @see https://github.com/artberri/diod/blob/main/docs/README.md
     */
    get builder(): ContainerBuilder | undefined;
    /**
     * The native DIOD container for this instance of VueDiodBuilder.
     * @see https://github.com/artberri/diod/blob/main/docs/README.md
     */
    get container(): Container | undefined;
}
